@@ -1,13 +1,8 @@
-import time
-
-from typing import Callable, Optional
+from typing import Optional, Union
 
 from pydantic import BaseModel
 
 from . import response as response_models
-from .response import APIDataBase
-from . import hubs as hub_models
-from . import partners as partner_models
 
 MODEL_TYPE = 'location_contacts'
 
@@ -34,3 +29,12 @@ class APILocationContactData(response_models.APIData):
 
 class ListAPILocationContactData(BaseModel):
     __root__: list[APILocationContactData]
+
+
+class APILocationContactResponse(response_models.APIResponse):
+    data: APILocationContactData
+
+
+class ListAPILocationContactResponse(response_models.ListAPIResponse):
+    data: list[Union[APILocationContactData, dict]]
+
