@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Union
 
 from pydantic import BaseModel
 
@@ -23,3 +23,11 @@ class APIPodData(response_models.APIData):
 
 class ListAPIPodData(BaseModel):
     __root__: list[APIPodData]
+
+
+class APIPodResponse(response_models.APIResponse):
+    data: APIPodData
+
+
+class ListAPIPodResponse(response_models.ListAPIResponse):
+    data: list[Union[APIPodData, dict]]
